summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2013-11-23 18:28:26 -0600
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2013-11-23 18:41:43 -0600
commit1c6e5f8caae66f45bfe76d59632aebf95c6c66d9 (patch)
tree010441233a0fafa621cb79eb931bb617ccd8aa1f
parent27ae9362d8c5e998de57fd14f5235915d9e7b995 (diff)
downloadlibpng-1.6.8beta01.tar.gz
[libpng16] Imported from libpng-1.6.8beta01.tarv1.6.8beta01
-rw-r--r--ANNOUNCE4
-rw-r--r--CHANGES2
-rw-r--r--LICENSE4
-rw-r--r--README2
-rw-r--r--arm/filter_neon.S5
-rw-r--r--arm/filter_neon_intrinsics.c4
-rw-r--r--contrib/pngminim/encoder/pngusr.dfa3
-rw-r--r--libpng-manual.txt6
-rw-r--r--libpng.314
-rw-r--r--libpngpf.32
-rw-r--r--png.52
-rw-r--r--png.c4
-rw-r--r--png.h10
-rw-r--r--pngconf.h2
-rw-r--r--projects/vstudio/readme.txt2
-rw-r--r--projects/vstudio/zlib.props2
-rw-r--r--scripts/README.txt2
-rw-r--r--scripts/pnglibconf.h.prebuilt2
18 files changed, 37 insertions, 35 deletions
diff --git a/ANNOUNCE b/ANNOUNCE
index 23b25c5a1..0953a8f8a 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,5 +1,5 @@
-Libpng 1.6.8beta01 - November 23, 2013
+Libpng 1.6.8beta01 - November 24, 2013
This is not intended to be a public release. It will be replaced
within a few weeks by a public version or by another test version.
@@ -26,7 +26,7 @@ Other information:
Changes since the last public release (1.6.7):
-Version 1.6.8beta01 [November 23, 2013]
+Version 1.6.8beta01 [November 24, 2013]
Changed #ifdef PNG_HANDLE_AS_UNKNOWN_SUPPORTED in pngpread.c to
#ifdef PNG_SET_UNKNOWN_CHUNKS_SUPPORTED to be consistent with
what is in pngpriv.h.
diff --git a/CHANGES b/CHANGES
index 02b134dd7..7d70a8fcb 100644
--- a/CHANGES
+++ b/CHANGES
@@ -4713,7 +4713,7 @@ Version 1.6.7rc02 [November 7, 2013]
Version 1.6.7 [November 14, 2013]
-Version 1.6.8beta01 [November 23, 2013]
+Version 1.6.8beta01 [November 24, 2013]
Moved prototype for png_handle_unknown() in pngpriv.h outside of
the #ifdef PNG_SET_UNKNOWN_CHUNKS_SUPPORTED/#endif block.
Added "-Wall" to CFLAGS in contrib/pngminim/*/makefile
diff --git a/LICENSE b/LICENSE
index 28641220e..864ff0482 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.6.8beta01, November 14, 2013, are
+libpng versions 1.2.6, August 15, 2004, through 1.6.8beta01, November 24, 2013, are
Copyright (c) 2004, 2006-2013 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-November 14, 2013
+November 24, 2013
diff --git a/README b/README
index eb079a465..e8f045aeb 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.6.8beta01 - November 14, 2013 (shared library 16.0)
+README for libpng version 1.6.8beta01 - November 24, 2013 (shared library 16.0)
See the note about version numbers near the top of png.h
See INSTALL for instructions on how to install libpng.
diff --git a/arm/filter_neon.S b/arm/filter_neon.S
index 3d1ccf505..0d7b71062 100644
--- a/arm/filter_neon.S
+++ b/arm/filter_neon.S
@@ -3,7 +3,7 @@
*
* Copyright (c) 2013 Glenn Randers-Pehrson
* Written by Mans Rullgard, 2011.
- * Last changed in libpng 1.6.7 [November 14, 2013]
+ * Last changed in libpng 1.6.8 [(PENDING RELEASE)]
*
* This code is released under the libpng license.
* For conditions of distribution and use, see the disclaimer
@@ -11,7 +11,8 @@
*/
/* This is required to get the symbol renames, which are #defines, and also
- * includes the definition (or not) of PNG_ARM_NEON_OPT.
+ * includes the definition (or not) of PNG_ARM_NEON_OPT and
+ * PNG_ARM_NEON_IMPLEMENTATION.
*/
#define PNG_VERSION_INFO_ONLY
#include "../pngpriv.h"
diff --git a/arm/filter_neon_intrinsics.c b/arm/filter_neon_intrinsics.c
index e6a0217ab..64f12fc0d 100644
--- a/arm/filter_neon_intrinsics.c
+++ b/arm/filter_neon_intrinsics.c
@@ -5,7 +5,7 @@
* Written by James Yu <james.yu at linaro.org>, October 2013.
* Based on filter_neon.S, written by Mans Rullgard, 2011.
*
- * Last changed in libpng 1.6.7 [November 14, 2013]
+ * Last changed in libpng 1.6.8 [(PENDING RELEASE)]
*
* This code is released under the libpng license.
* For conditions of distribution and use, see the disclaimer
@@ -15,7 +15,7 @@
#include "../pngpriv.h"
/* This code requires -mfpu=neon on the command line: */
-#if PNG_ARM_NEON_IMPLEMENTATION == 1 /* intrinsics code */
+#if PNG_ARM_NEON_IMPLEMENTATION == 1 /* intrinsics code from pngpriv.h */
#include <arm_neon.h>
diff --git a/contrib/pngminim/encoder/pngusr.dfa b/contrib/pngminim/encoder/pngusr.dfa
index b6cf53daa..1fc24f3f2 100644
--- a/contrib/pngminim/encoder/pngusr.dfa
+++ b/contrib/pngminim/encoder/pngusr.dfa
@@ -13,7 +13,8 @@ everything = off
# Switch on the write code - this makes a minimalist encoder
option WRITE on
-# These 2 options are required if you need to read PGM (P1 or P4) PGM files.
+
+# These 2 options are required if you need to read PBM (P1 or P4) files.
option WRITE_INVERT on
option WRITE_PACK on
diff --git a/libpng-manual.txt b/libpng-manual.txt
index 750eb3bc2..301b93aaf 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.6.8beta01 - November 14, 2013
+ libpng version 1.6.8beta01 - November 24, 2013
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2013 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.6.8beta01 - November 14, 2013
+ libpng versions 0.97, January 1998, through 1.6.8beta01 - November 24, 2013
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2013 Glenn Randers-Pehrson
@@ -5232,7 +5232,7 @@ Other rules can be inferred by inspecting the libpng source.
XVI. Y2K Compliance in libpng
-November 14, 2013
+November 24, 2013
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
diff --git a/libpng.3 b/libpng.3
index 4c33aacee..193f5ae44 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,4 +1,4 @@
-.TH LIBPNG 3 "November 14, 2013"
+.TH LIBPNG 3 "November 24, 2013"
.SH NAME
libpng \- Portable Network Graphics (PNG) Reference Library 1.6.8beta01
.SH SYNOPSIS
@@ -504,7 +504,7 @@ Following is a copy of the libpng-manual.txt file that accompanies libpng.
.SH LIBPNG.TXT
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.6.8beta01 - November 14, 2013
+ libpng version 1.6.8beta01 - November 24, 2013
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2013 Glenn Randers-Pehrson
@@ -515,7 +515,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.6.8beta01 - November 14, 2013
+ libpng versions 0.97, January 1998, through 1.6.8beta01 - November 24, 2013
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2013 Glenn Randers-Pehrson
@@ -5737,7 +5737,7 @@ Other rules can be inferred by inspecting the libpng source.
.SH XVI. Y2K Compliance in libpng
-November 14, 2013
+November 24, 2013
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
@@ -6025,7 +6025,7 @@ possible without all of you.
Thanks to Frank J. T. Wojcik for helping with the documentation.
-Libpng version 1.6.8beta01 - November 14, 2013:
+Libpng version 1.6.8beta01 - November 24, 2013:
Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
@@ -6048,7 +6048,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.6.8beta01, November 14, 2013, are
+libpng versions 1.2.6, August 15, 2004, through 1.6.8beta01, November 24, 2013, are
Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -6147,7 +6147,7 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-November 14, 2013
+November 24, 2013
.\" end of man page
diff --git a/libpngpf.3 b/libpngpf.3
index d50804563..296ec43f4 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,4 +1,4 @@
-.TH LIBPNGPF 3 "November 14, 2013"
+.TH LIBPNGPF 3 "November 24, 2013"
.SH NAME
libpng \- Portable Network Graphics (PNG) Reference Library 1.6.8beta01
(private functions)
diff --git a/png.5 b/png.5
index 978af1c11..40c4e68ac 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "November 14, 2013"
+.TH PNG 5 "November 24, 2013"
.SH NAME
png \- Portable Network Graphics (PNG) format
.SH DESCRIPTION
diff --git a/png.c b/png.c
index 70777723d..0b170ab27 100644
--- a/png.c
+++ b/png.c
@@ -772,13 +772,13 @@ png_get_copyright(png_const_structrp png_ptr)
#else
# ifdef __STDC__
return PNG_STRING_NEWLINE \
- "libpng version 1.6.8beta01 - November 22, 2013" PNG_STRING_NEWLINE \
+ "libpng version 1.6.8beta01 - November 24, 2013" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2013 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE;
# else
- return "libpng version 1.6.8beta01 - November 22, 2013\
+ return "libpng version 1.6.8beta01 - November 24, 2013\
Copyright (c) 1998-2013 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/pngconf.h b/pngconf.h
index fd19c9827..f5b06e8a1 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.6.8beta01 - November 14, 2013
+ * libpng version 1.6.8beta01 - November 24, 2013
*
* Copyright (c) 1998-2013 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index d32a26996..8994a12db 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
VisualStudio instructions
-libpng version 1.6.8beta01 - November 14, 2013
+libpng version 1.6.8beta01 - November 24, 2013
Copyright (c) 1998-2010 Glenn Randers-Pehrson
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 36c3f748b..56be4dd48 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
<!--
* zlib.props - location of zlib source
*
- * libpng version 1.6.8beta01 - November 14, 2013
+ * libpng version 1.6.8beta01 - November 24, 2013
*
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
*
diff --git a/scripts/README.txt b/scripts/README.txt
index bde6d237d..c273ed56b 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,5 +1,5 @@
-Makefiles for libpng version 1.6.8beta01 - November 14, 2013
+Makefiles for libpng version 1.6.8beta01 - November 24, 2013
pnglibconf.h.prebuilt => Stores configuration settings
makefile.linux => Linux/ELF makefile
diff --git a/scripts/pnglibconf.h.prebuilt b/scripts/pnglibconf.h.prebuilt
index 7136454e9..df42472c9 100644
--- a/scripts/pnglibconf.h.prebuilt
+++ b/scripts/pnglibconf.h.prebuilt
@@ -2,7 +2,7 @@
/* pnglibconf.h - library build configuration */
-/* Libpng version 1.6.8beta01 - November 14, 2013 */
+/* Libpng version 1.6.8beta01 - November 24, 2013 */
/* Copyright (c) 1998-2013 Glenn Randers-Pehrson */
diff --git a/png.h b/png.h
index 43c882048..e46b7ef9e 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.6.8beta01 - November 14, 2013
* Copyright (c) 1998-2013 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.6.8beta01 - November 14, 2013: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -218,7 +218,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.6.8beta01, November 14, 2013, are
* Copyright (c) 2004, 2006-2013 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -330,7 +330,7 @@
* Y2K compliance in libpng:
* =========================
*
- * November 14, 2013
+ * November 24, 2013
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
@@ -398,7 +398,7 @@
/* Version information for png.h - this should match the version in png.c */
#define PNG_LIBPNG_VER_STRING "1.6.8beta01"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.6.8beta01 - November 14, 2013\n"
+ " libpng version 1.6.8beta01 - November 24, 2013\n"
#define PNG_LIBPNG_VER_SONUM 16
#define PNG_LIBPNG_VER_DLLNUM 16
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.6.8beta01 - November 14, 2013
+ * libpng version 1.6.8beta01 - November 24, 2013
* Copyright (c) 1998-2013 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.6.8beta01 - November 14, 2013: Glenn
+ * libpng versions 0.97, January 1998, through 1.6.8beta01 - November 24, 2013: Glenn
* See also "Contributing Authors", below.
*
@@ -218,7 +218,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.6.8beta01, November 14, 2013, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.6.8beta01, November 24, 2013, are
* Copyright (c) 2004, 2006-2013 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5